import { ErrorCodes, IAuthManager, IAuthManagerOptions, IAutorizeOptions, IPermission, IRole, extendOpts, permission, permissions, scopes } from "@iamjs/core/types";
/**
 * Role class
 */
declare class Role implements IRole {
    permissions: IPermission[];
    /**
     * Role constructor
     */
    constructor(permissions?: IPermission[]);
    private formatPermission;
    addPermission(permission: IPermission): this;
    removePermission(resource: string): this;
    updatePermission(permission: IPermission): this;
    canCreate(resource: string): boolean;
    canRead(resource: string): boolean;
    canUpdate(resource: string): boolean;
    canDelete(resource: string): boolean;
    canList(resource: string): boolean;
    can(permission: permission, resource: string): boolean;
    canAny(permissions: permissions, resource: string): boolean;
    canAll(permissions: permissions, resource: string): boolean;
    extend(role: IRole, options?: extendOpts): this;
    generate(format?: "json" | "object"): string | object;
    toJSON(): string;
    toObject(): object;
    /**
     * Load a role from a json string
     * @param json - Json string to load
     */
    static fromJSON(json: string): IRole;
    /**
     * Load a role from a javascript object
     * @param object - Object to load
     */
    static fromObject(object: {
        [key: string]: any;
    }): IRole;
    static validate(role: IRole, cb?: (result: boolean, error?: Error) => void): boolean;
    static validatePermission(permission: IPermission): boolean;
}
/**
 * The error class for the `AuthManager`
 */
declare class AuthError extends Error {
    code: ErrorCodes;
    constructor(code: ErrorCodes);
    static throw_error(code: ErrorCodes): never;
    static throw_unknown_error(error: any): never;
}
declare class AuthManager implements IAuthManager {
    roles: Map<string, IRole>;
    resources: Set<string>;
    constructor(options: IAuthManagerOptions);
    private _checkRole;
    private _checkResource;
    private _getRole;
    private _verifyPermissionsStrict;
    private _verifyPermissionsLoose;
    private _verifyOptions;
    authorizeRole(options: IAutorizeOptions): boolean;
}
export { AuthError, AuthManager, Role };
export type { ErrorCodes, IAuthManager, IAuthManagerOptions, IAutorizeOptions, IPermission, IRole, extendOpts, permission, permissions, scopes, };
